@@ -285,6 +285,7 @@ ctv2html <- function(x,
             "<html>",
             "<head>",
             paste0("  <title>", title, "</title>"),
+            if(!is.null(x$url)) sprintf('  <link rel="canonical" href="%s" />', x$url),
             if(!is.null(css)) paste0('  <link rel="stylesheet" type="text/css" href="', css, '" />'),
             '  <meta http-equiv="content-type" content="text/html; charset=UTF-8" />',
             sprintf('  <meta name="citation_title" content="%s" />', title),
@@ -437,8 +438,9 @@ repos_update_views <- function(repos = ".", cran = TRUE,
              "<html>",
              "",
 	     "<head>",
-             paste0("  <title>", reposname, " Task Views</title>"),
-             paste0('  <link rel="stylesheet" type="text/css" href="', css, '" />'),
+             sprintf("  <title>%s Task Views</title>", reposname),
+             if(cran) '  <link rel="canonical" href="https://CRAN.R-project.org/web/views/" />' else NULL,
+             sprintf('  <link rel="stylesheet" type="text/css" href="%s" />', css),
              '  <meta http-equiv="content-type" content="text/html; charset=UTF-8" />',
              sprintf('  <meta name="citation_title" content="%s Task Views" />', reposname),
              sprintf('  <meta name="citation_author" content="%s" />', reposname),
@@ -456,7 +458,7 @@ repos_update_views <- function(repos = ".", cran = TRUE,
              "</head>",
 	     "",
 	     "<body>",
-             paste0("<h1>", reposname, " Task Views</h1>"),
+             sprintf("<h1>%s Task Views</h1>", reposname),
 	     "",
 	     sprintf("<p>%s task views aim to provide guidance which packages on %s", reposname, reposname),
 	     "are relevant for tasks related to a certain topic. They give a brief overview of the included packages",
